summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile23
-rw-r--r--debian/changelog11
-rwxr-xr-xfunctions/common.sh2
-rwxr-xr-xfunctions/defaults.sh8
-rwxr-xr-xfunctions/legacy.sh18
-rwxr-xr-xhelpers/lh7
-rwxr-xr-xhelpers/lh_binary2
-rwxr-xr-xhelpers/lh_binary_chroot2
-rwxr-xr-xhelpers/lh_binary_debian-installer2
-rwxr-xr-xhelpers/lh_binary_disk2
-rwxr-xr-xhelpers/lh_binary_encryption2
-rwxr-xr-xhelpers/lh_binary_grub2
-rwxr-xr-xhelpers/lh_binary_grub22
-rwxr-xr-xhelpers/lh_binary_includes2
-rwxr-xr-xhelpers/lh_binary_iso2
-rwxr-xr-xhelpers/lh_binary_linux-image2
-rwxr-xr-xhelpers/lh_binary_local-hooks2
-rwxr-xr-xhelpers/lh_binary_local-includes2
-rwxr-xr-xhelpers/lh_binary_local-packageslists2
-rwxr-xr-xhelpers/lh_binary_manifest2
-rwxr-xr-xhelpers/lh_binary_md5sum2
-rwxr-xr-xhelpers/lh_binary_memtest2
-rwxr-xr-xhelpers/lh_binary_net2
-rwxr-xr-xhelpers/lh_binary_rootfs2
-rwxr-xr-xhelpers/lh_binary_silo2
-rwxr-xr-xhelpers/lh_binary_syslinux2
-rwxr-xr-xhelpers/lh_binary_tar2
-rwxr-xr-xhelpers/lh_binary_usb-hdd2
-rwxr-xr-xhelpers/lh_binary_virtual-hdd2
-rwxr-xr-xhelpers/lh_binary_win32-loader2
-rwxr-xr-xhelpers/lh_binary_yaboot2
-rwxr-xr-xhelpers/lh_bootstrap2
-rwxr-xr-xhelpers/lh_bootstrap_cache2
-rwxr-xr-xhelpers/lh_bootstrap_cdebootstrap2
-rwxr-xr-xhelpers/lh_bootstrap_copy2
-rwxr-xr-xhelpers/lh_bootstrap_debootstrap8
-rwxr-xr-xhelpers/lh_build2
-rwxr-xr-xhelpers/lh_chroot2
-rwxr-xr-xhelpers/lh_chroot_apt2
-rwxr-xr-xhelpers/lh_chroot_cache2
-rwxr-xr-xhelpers/lh_chroot_debianchroot2
-rwxr-xr-xhelpers/lh_chroot_devpts2
-rwxr-xr-xhelpers/lh_chroot_dpkg2
-rwxr-xr-xhelpers/lh_chroot_hacks2
-rwxr-xr-xhelpers/lh_chroot_hooks2
-rwxr-xr-xhelpers/lh_chroot_hostname2
-rwxr-xr-xhelpers/lh_chroot_hosts2
-rwxr-xr-xhelpers/lh_chroot_install-packages2
-rwxr-xr-xhelpers/lh_chroot_interactive2
-rwxr-xr-xhelpers/lh_chroot_linux-image2
-rwxr-xr-xhelpers/lh_chroot_local-hooks2
-rwxr-xr-xhelpers/lh_chroot_local-includes2
-rwxr-xr-xhelpers/lh_chroot_local-packages2
-rwxr-xr-xhelpers/lh_chroot_local-patches2
-rwxr-xr-xhelpers/lh_chroot_local-preseed2
-rwxr-xr-xhelpers/lh_chroot_localization2
-rwxr-xr-xhelpers/lh_chroot_packages2
-rwxr-xr-xhelpers/lh_chroot_packageslists2
-rwxr-xr-xhelpers/lh_chroot_preseed2
-rwxr-xr-xhelpers/lh_chroot_proc2
-rwxr-xr-xhelpers/lh_chroot_resolv2
-rwxr-xr-xhelpers/lh_chroot_selinuxfs2
-rwxr-xr-xhelpers/lh_chroot_sources26
-rwxr-xr-xhelpers/lh_chroot_symlinks2
-rwxr-xr-xhelpers/lh_chroot_sysfs2
-rwxr-xr-xhelpers/lh_chroot_sysv-rc2
-rwxr-xr-xhelpers/lh_chroot_sysvinit2
-rwxr-xr-xhelpers/lh_chroot_tasks2
-rwxr-xr-xhelpers/lh_clean2
-rwxr-xr-xhelpers/lh_config16
-rwxr-xr-xhelpers/lh_source2
-rwxr-xr-xhelpers/lh_source_debian2
-rwxr-xr-xhelpers/lh_source_debian-live2
-rwxr-xr-xhelpers/lh_source_disk2
-rwxr-xr-xhelpers/lh_source_iso2
-rwxr-xr-xhelpers/lh_source_md5sum2
-rwxr-xr-xhelpers/lh_source_net2
-rwxr-xr-xhelpers/lh_source_tar2
-rwxr-xr-xhelpers/lh_source_usb-hdd2
-rwxr-xr-xhelpers/lh_source_virtual-hdd2
-rwxr-xr-xhelpers/lh_testroot2
-rwxr-xr-xhelpers/live-helper2
-rwxr-xr-xlive-helper.sh (renamed from functions.sh)0
-rw-r--r--manpages/lh_config.en.16
-rw-r--r--manpages/po4a/de/lh_config.en.1.po10
-rw-r--r--manpages/po4a/fr/lh_config.en.1.po6
-rw-r--r--manpages/po4a/pot/lh_config.en.1.pot6
87 files changed, 139 insertions, 154 deletions
diff --git a/Makefile b/Makefile
index 5bbe14c..aa61e1c 100644
--- a/Makefile
+++ b/Makefile
@@ -8,7 +8,7 @@ all: test install
test:
# Checking for syntax errors
- for SCRIPT in functions.sh functions/* examples/*/*.sh helpers/* hooks/*; \
+ for SCRIPT in live-helper.sh functions/* examples/*/*.sh helpers/* hooks/*; \
do \
sh -n $$SCRIPT; \
done
@@ -16,7 +16,7 @@ test:
# Checking for bashisms
if [ -x /usr/bin/checkbashisms ]; \
then \
- checkbashisms functions.sh functions/* examples/*/*.sh helpers/* hooks/*; \
+ checkbashisms live-helper.sh functions/* examples/*/*.sh helpers/* hooks/*; \
else \
echo "WARNING: skipping bashism test - you need to install devscripts."; \
fi
@@ -25,13 +25,13 @@ build:
@echo "Nothing to build."
install:
- # Installing executables
- mkdir -p $(DESTDIR)/usr/bin
- cp helpers/* $(DESTDIR)/usr/bin
-
# Installing shared data
mkdir -p $(DESTDIR)/usr/share/live-helper
- cp -r data examples functions.sh functions hooks includes lists templates $(DESTDIR)/usr/share/live-helper
+ cp -r data examples live-helper.sh functions helpers hooks includes lists templates $(DESTDIR)/usr/share/live-helper
+
+ # Installing executables
+ mkdir -p $(DESTDIR)/usr/bin
+ mv $(DESTDIR)/usr/share/live-helper/helpers/lh $(DESTDIR)/usr/share/live-helper/helpers/live-helper $(DESTDIR)/usr/bin
# Installing documentation
mkdir -p $(DESTDIR)/usr/share/doc/live-helper
@@ -64,15 +64,12 @@ install:
mkdir -p $(DESTDIR)/var/log
uninstall:
- # Uninstalling executables
- for HELPER in helpers/*; \
- do \
- rm -f $(DESTDIR)/usr/bin/$$(basename $$HELPER); \
- done
-
# Uninstalling shared data
rm -rf $(DESTDIR)/usr/share/live-helper
+ # Uninstalling executables
+ rm -f $(DESTDIR)/usr/bin/lh $(DESTDIR)/usr/bin/live-helper
+
# Uninstalling documentation
rm -rf $(DESTDIR)/usr/share/doc/live-helper
diff --git a/debian/changelog b/debian/changelog
index 51d6025..48e5332 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,9 +1,12 @@
-live-helper (1.0.6-2) unstable; urgency=high
+live-helper (2.0~a1-1) experimental; urgency=low
- * Replacing sed 4.2 command to assemble debootstraps components option
- with a less advanced one, in order to work on legacy distributions.
+ * Renaming categories to archive areas (Closes: #519690).
+ * Renaming functions.sh to live-helper.sh.
+ * Installing helpers to /usr/share/live-helper/helpers instead of
+ /usr/bin.
+ * Removing legacy function for dashed commands.
- -- Daniel Baumann <daniel@debian.org> Sun, 22 Nov 2009 13:35:50 +0100
+ -- Daniel Baumann <daniel@debian.org> Sun, 15 Nov 2009 22:42:59 +0100
live-helper (1.0.6-1) unstable; urgency=medium
diff --git a/functions/common.sh b/functions/common.sh
index 2be9e54..184ebe0 100755
--- a/functions/common.sh
+++ b/functions/common.sh
@@ -9,7 +9,7 @@
PROGRAM="$(basename ${0})"
PACKAGE="live-helper"
-VERSION="1.0.6-1"
+VERSION="2.0~a1-1"
CONFIG_VERSION="$(echo ${VERSION} | awk -F- '{ print $1 }')"
PATH="${PWD}/scripts:${PATH}"
diff --git a/functions/legacy.sh b/functions/legacy.sh
deleted file mode 100755
index 422c20d..0000000
--- a/functions/legacy.sh
+++ /dev/null
@@ -1,18 +0,0 @@
-#!/bin/sh
-
-# legacy.sh - handle live-helper 2.x warnigns
-# Copyright (C) 2006-2009 Daniel Baumann <daniel@debian.org>
-#
-# live-helper comes with ABSOLUTELY NO WARRANTY; for details see COPYING.
-# This is free software, and you are welcome to redistribute it
-# under certain conditions; see COPYING for details.
-
-# Obsoleting 'lh_foo_bar' calls in favour for 'lh foo_bar'
-
-BASENAME="$(basename ${0})"
-
-if [ -z "${LH}" ] && [ "$(echo ${BASENAME} | awk '{ print $1 }')" != "lh" ]
-then
- Echo_warning "live-helper 2.0 will deprecate all dashed forms of commands."
- Echo_warning "Please use \'$(echo ${BASENAME} | sed -e 's|lh_|lh |')\' instead of \'${BASENAME}\'."
-fi
diff --git a/helpers/lh b/helpers/lh
index bb4d76b..ecf9b4a 100755
--- a/helpers/lh
+++ b/helpers/lh
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'utility to build Debian Live systems')"
@@ -34,7 +34,10 @@ case "${1}" in
COMMAND="${1}"
shift
- if [ -x "$(which lh_${COMMAND} 2>/dev/null)" ]
+ if [ -x /usr/share/live-helper/helpers/lh_${COMMAND} ]
+ then
+ LH=1 exec /usr/share/live-helper/helpers/lh_"${COMMAND}" "${@}"
+ elif [ -x "$(which lh_${COMMAND} 2>/dev/null)" ]
then
LH=1 exec lh_"${COMMAND}" "${@}"
else
diff --git a/helpers/lh_binary b/helpers/lh_binary
index 271bfd7..f5508c5 100755
--- a/helpers/lh_binary
+++ b/helpers/lh_binary
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build binary images')"
diff --git a/helpers/lh_binary_chroot b/helpers/lh_binary_chroot
index cef600e..6194826 100755
--- a/helpers/lh_binary_chroot
+++ b/helpers/lh_binary_chroot
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'copy chroot into chroot')"
diff --git a/helpers/lh_binary_debian-installer b/helpers/lh_binary_debian-installer
index 32d0ce0..daa927f 100755
--- a/helpers/lh_binary_debian-installer
+++ b/helpers/lh_binary_debian-installer
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install debian-installer into binary')"
diff --git a/helpers/lh_binary_disk b/helpers/lh_binary_disk
index 2d209fb..8905e6d 100755
--- a/helpers/lh_binary_disk
+++ b/helpers/lh_binary_disk
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install disk information into binary')"
diff --git a/helpers/lh_binary_encryption b/helpers/lh_binary_encryption
index d64af37..711f3da 100755
--- a/helpers/lh_binary_encryption
+++ b/helpers/lh_binary_encryption
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'encrypts rootfs')"
diff --git a/helpers/lh_binary_grub b/helpers/lh_binary_grub
index d0e3221..0d23ebb 100755
--- a/helpers/lh_binary_grub
+++ b/helpers/lh_binary_grub
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'installs grub into binary')"
diff --git a/helpers/lh_binary_grub2 b/helpers/lh_binary_grub2
index 7be3bf5..2946214 100755
--- a/helpers/lh_binary_grub2
+++ b/helpers/lh_binary_grub2
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'installs grub2 into binary')"
diff --git a/helpers/lh_binary_includes b/helpers/lh_binary_includes
index 57d33cd..7c8ed66 100755
--- a/helpers/lh_binary_includes
+++ b/helpers/lh_binary_includes
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'copy files into binary')"
diff --git a/helpers/lh_binary_iso b/helpers/lh_binary_iso
index a4dc2ac..edf21a0 100755
--- a/helpers/lh_binary_iso
+++ b/helpers/lh_binary_iso
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build iso binary image')"
diff --git a/helpers/lh_binary_linux-image b/helpers/lh_binary_linux-image
index 0b1c542..e3bcb38 100755
--- a/helpers/lh_binary_linux-image
+++ b/helpers/lh_binary_linux-image
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install linux-image into binary')"
diff --git a/helpers/lh_binary_local-hooks b/helpers/lh_binary_local-hooks
index fbc99e5..704879b 100755
--- a/helpers/lh_binary_local-hooks
+++ b/helpers/lh_binary_local-hooks
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'execute local hooks in binary')"
diff --git a/helpers/lh_binary_local-includes b/helpers/lh_binary_local-includes
index 95e0a1b..63986ae 100755
--- a/helpers/lh_binary_local-includes
+++ b/helpers/lh_binary_local-includes
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'copy files into binary')"
diff --git a/helpers/lh_binary_local-packageslists b/helpers/lh_binary_local-packageslists
index 60006d7..43d8005 100755
--- a/helpers/lh_binary_local-packageslists
+++ b/helpers/lh_binary_local-packageslists
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install local packages into binary')"
diff --git a/helpers/lh_binary_manifest b/helpers/lh_binary_manifest
index 981699a..4c40115 100755
--- a/helpers/lh_binary_manifest
+++ b/helpers/lh_binary_manifest
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'create manifest')"
diff --git a/helpers/lh_binary_md5sum b/helpers/lh_binary_md5sum
index 1ca7a1e..6cc88df 100755
--- a/helpers/lh_binary_md5sum
+++ b/helpers/lh_binary_md5sum
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'create binary md5sums')"
diff --git a/helpers/lh_binary_memtest b/helpers/lh_binary_memtest
index edd9225..cfe455c 100755
--- a/helpers/lh_binary_memtest
+++ b/helpers/lh_binary_memtest
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'installs a memtest into binary')"
diff --git a/helpers/lh_binary_net b/helpers/lh_binary_net
index 15f6388..05ecce7 100755
--- a/helpers/lh_binary_net
+++ b/helpers/lh_binary_net
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build netboot binary image')"
diff --git a/helpers/lh_binary_rootfs b/helpers/lh_binary_rootfs
index f254d84..aab7e5a 100755
--- a/helpers/lh_binary_rootfs
+++ b/helpers/lh_binary_rootfs
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build rootfs image')"
diff --git a/helpers/lh_binary_silo b/helpers/lh_binary_silo
index 18a6b87..e3734c9 100755
--- a/helpers/lh_binary_silo
+++ b/helpers/lh_binary_silo
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'installs silo into binary')"
diff --git a/helpers/lh_binary_syslinux b/helpers/lh_binary_syslinux
index 67ba35b..75d6cd5 100755
--- a/helpers/lh_binary_syslinux
+++ b/helpers/lh_binary_syslinux
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'installs syslinux into binary')"
diff --git a/helpers/lh_binary_tar b/helpers/lh_binary_tar
index 7c769d5..019b42f 100755
--- a/helpers/lh_binary_tar
+++ b/helpers/lh_binary_tar
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build harddisk binary image')"
diff --git a/helpers/lh_binary_usb-hdd b/helpers/lh_binary_usb-hdd
index 8be8aed..997c24b 100755
--- a/helpers/lh_binary_usb-hdd
+++ b/helpers/lh_binary_usb-hdd
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build binary image')"
diff --git a/helpers/lh_binary_virtual-hdd b/helpers/lh_binary_virtual-hdd
index b5d7876..83dec0c 100755
--- a/helpers/lh_binary_virtual-hdd
+++ b/helpers/lh_binary_virtual-hdd
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build binary image')"
diff --git a/helpers/lh_binary_win32-loader b/helpers/lh_binary_win32-loader
index b25a268..d5a97e1 100755
--- a/helpers/lh_binary_win32-loader
+++ b/helpers/lh_binary_win32-loader
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'copy win32-loader into binary')"
diff --git a/helpers/lh_binary_yaboot b/helpers/lh_binary_yaboot
index a80833c..6f528c1 100755
--- a/helpers/lh_binary_yaboot
+++ b/helpers/lh_binary_yaboot
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'installs yaboot into binary')"
diff --git a/helpers/lh_bootstrap b/helpers/lh_bootstrap
index 696fdf9..823c465 100755
--- a/helpers/lh_bootstrap
+++ b/helpers/lh_bootstrap
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'bootstrap a Debian system')"
diff --git a/helpers/lh_bootstrap_cache b/helpers/lh_bootstrap_cache
index 5a34890..a025428 100755
--- a/helpers/lh_bootstrap_cache
+++ b/helpers/lh_bootstrap_cache
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'cache bootstrap stage')"
diff --git a/helpers/lh_bootstrap_cdebootstrap b/helpers/lh_bootstrap_cdebootstrap
index 0ac72a7..2694aba 100755
--- a/helpers/lh_bootstrap_cdebootstrap
+++ b/helpers/lh_bootstrap_cdebootstrap
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'bootstrap a Debian system with cdebootstrap(1)')"
diff --git a/helpers/lh_bootstrap_copy b/helpers/lh_bootstrap_copy
index b70fcea..456c89d 100755
--- a/helpers/lh_bootstrap_copy
+++ b/helpers/lh_bootstrap_copy
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'bootstrap by copying the host system')"
diff --git a/helpers/lh_bootstrap_debootstrap b/helpers/lh_bootstrap_debootstrap
index d9fcdd0..b347a6b 100755
--- a/helpers/lh_bootstrap_debootstrap
+++ b/helpers/lh_bootstrap_debootstrap
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'bootstrap a Debian system with debootstrap(8)')"
@@ -57,10 +57,10 @@ then
DEBOOTSTRAP_OPTIONS="${DEBOOTSTRAP_OPTIONS} --arch ${LH_ARCHITECTURE}"
fi
-if [ "${LH_CATEGORIES}" != "main" ]
+if [ "${LH_ARCHIVE_AREAS}" != "main" ]
then
- # Modify categories to remove leading/trailing whitespaces and replace other whitepspace with commas
- DEBOOTSTRAP_OPTIONS="${DEBOOTSTRAP_OPTIONS} --components $(echo ${LH_ARCHIVE_AREAS} | sed -e 's| |,|g')"
+ # Modify archive areas to remove leading/trailing whitespaces and replace other whitepspace with commas
+ DEBOOTSTRAP_OPTIONS="${DEBOOTSTRAP_OPTIONS} --components $(echo ${LH_ARCHIVE_AREAS} | sed -E -e 's/^[ \t]*//;s/[ \t]*$//' -e 's/[ \t]+/,/g')"
fi
if [ -n "${LH_BOOTSTRAP_CONFIG}" ]
diff --git a/helpers/lh_build b/helpers/lh_build
index 43a33de..7d5abf0 100755
--- a/helpers/lh_build
+++ b/helpers/lh_build
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Read meta config
if [ "${1}" != "noautoconfig" ] && [ -x scripts/build ]
diff --git a/helpers/lh_chroot b/helpers/lh_chroot
index 6cb705e..df14a0f 100755
--- a/helpers/lh_chroot
+++ b/helpers/lh_chroot
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'customize the Debian system')"
diff --git a/helpers/lh_chroot_apt b/helpers/lh_chroot_apt
index 1c35849..4396aeb 100755
--- a/helpers/lh_chroot_apt
+++ b/helpers/lh_chroot_apt
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /etc/apt/apt.conf')"
diff --git a/helpers/lh_chroot_cache b/helpers/lh_chroot_cache
index 6a21fcb..dacf8c0 100755
--- a/helpers/lh_chroot_cache
+++ b/helpers/lh_chroot_cache
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'cache chroot stage')"
diff --git a/helpers/lh_chroot_debianchroot b/helpers/lh_chroot_debianchroot
index e0f7983..6916d2d 100755
--- a/helpers/lh_chroot_debianchroot
+++ b/helpers/lh_chroot_debianchroot
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /etc/debian_chroot')"
diff --git a/helpers/lh_chroot_devpts b/helpers/lh_chroot_devpts
index 7624691..d652fe5 100755
--- a/helpers/lh_chroot_devpts
+++ b/helpers/lh_chroot_devpts
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'mount /dev/pts')"
diff --git a/helpers/lh_chroot_dpkg b/helpers/lh_chroot_dpkg
index f18526c..7fd6e67 100755
--- a/helpers/lh_chroot_dpkg
+++ b/helpers/lh_chroot_dpkg
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /sbin/dpkg')"
diff --git a/helpers/lh_chroot_hacks b/helpers/lh_chroot_hacks
index cc12630..5aa45a6 100755
--- a/helpers/lh_chroot_hacks
+++ b/helpers/lh_chroot_hacks
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'execute hacks in chroot')"
diff --git a/helpers/lh_chroot_hooks b/helpers/lh_chroot_hooks
index 4821d46..04fe487 100755
--- a/helpers/lh_chroot_hooks
+++ b/helpers/lh_chroot_hooks
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'execute hooks in chroot')"
diff --git a/helpers/lh_chroot_hostname b/helpers/lh_chroot_hostname
index 17b5499..9cafcf6 100755
--- a/helpers/lh_chroot_hostname
+++ b/helpers/lh_chroot_hostname
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /bin/hostname')"
diff --git a/helpers/lh_chroot_hosts b/helpers/lh_chroot_hosts
index 827a4ef..2b7fc25 100755
--- a/helpers/lh_chroot_hosts
+++ b/helpers/lh_chroot_hosts
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /etc/hosts')"
diff --git a/helpers/lh_chroot_install-packages b/helpers/lh_chroot_install-packages
index 01fc633..b200e0a 100755
--- a/helpers/lh_chroot_install-packages
+++ b/helpers/lh_chroot_install-packages
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install queued packages into chroot')"
diff --git a/helpers/lh_chroot_interactive b/helpers/lh_chroot_interactive
index b39be37..242cb66 100755
--- a/helpers/lh_chroot_interactive
+++ b/helpers/lh_chroot_interactive
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'make build interactive')"
diff --git a/helpers/lh_chroot_linux-image b/helpers/lh_chroot_linux-image
index cc2c8e8..76515ef 100755
--- a/helpers/lh_chroot_linux-image
+++ b/helpers/lh_chroot_linux-image
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /etc/kernel-img.conf')"
diff --git a/helpers/lh_chroot_local-hooks b/helpers/lh_chroot_local-hooks
index 878becb..5c076b0 100755
--- a/helpers/lh_chroot_local-hooks
+++ b/helpers/lh_chroot_local-hooks
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'execute local hooks in chroot')"
diff --git a/helpers/lh_chroot_local-includes b/helpers/lh_chroot_local-includes
index 5394d4b..3991750 100755
--- a/helpers/lh_chroot_local-includes
+++ b/helpers/lh_chroot_local-includes
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'copy local files into chroot')"
diff --git a/helpers/lh_chroot_local-packages b/helpers/lh_chroot_local-packages
index f4e5182..f2cdfb0 100755
--- a/helpers/lh_chroot_local-packages
+++ b/helpers/lh_chroot_local-packages
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'queue install of local packages into chroot')"
diff --git a/helpers/lh_chroot_local-patches b/helpers/lh_chroot_local-patches
index 42f8b44..303ffd1 100755
--- a/helpers/lh_chroot_local-patches
+++ b/helpers/lh_chroot_local-patches
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'apply local patches against chroot')"
diff --git a/helpers/lh_chroot_local-preseed b/helpers/lh_chroot_local-preseed
index 08dfab0..2256bab 100755
--- a/helpers/lh_chroot_local-preseed
+++ b/helpers/lh_chroot_local-preseed
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'execute local preseed in chroot')"
diff --git a/helpers/lh_chroot_localization b/helpers/lh_chroot_localization
index 3135f22..12104e7 100755
--- a/helpers/lh_chroot_localization
+++ b/helpers/lh_chroot_localization
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install localization packages into chroot')"
diff --git a/helpers/lh_chroot_packages b/helpers/lh_chroot_packages
index 9f9ba85..61a2fa6 100755
--- a/helpers/lh_chroot_packages
+++ b/helpers/lh_chroot_packages
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'queue install of packages into chroot')"
diff --git a/helpers/lh_chroot_packageslists b/helpers/lh_chroot_packageslists
index c437e0e..464369d 100755
--- a/helpers/lh_chroot_packageslists
+++ b/helpers/lh_chroot_packageslists
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'queue install of packages lists into chroot')"
diff --git a/helpers/lh_chroot_preseed b/helpers/lh_chroot_preseed
index 75d93b7..6058e73 100755
--- a/helpers/lh_chroot_preseed
+++ b/helpers/lh_chroot_preseed
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'execute preseed in chroot')"
diff --git a/helpers/lh_chroot_proc b/helpers/lh_chroot_proc
index 757b9c7..7878bf5 100755
--- a/helpers/lh_chroot_proc
+++ b/helpers/lh_chroot_proc
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'mount /proc')"
diff --git a/helpers/lh_chroot_resolv b/helpers/lh_chroot_resolv
index 3a2635e..0b24a23 100755
--- a/helpers/lh_chroot_resolv
+++ b/helpers/lh_chroot_resolv
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /etc/resolv.conf')"
diff --git a/helpers/lh_chroot_selinuxfs b/helpers/lh_chroot_selinuxfs
index c30d7cd..1a81c57 100755
--- a/helpers/lh_chroot_selinuxfs
+++ b/helpers/lh_chroot_selinuxfs
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'mount /selinux')"
diff --git a/helpers/lh_chroot_sources b/helpers/lh_chroot_sources
index 0da8701..31c6124 100755
--- a/helpers/lh_chroot_sources
+++ b/helpers/lh_chroot_sources
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /etc/apt/sources.list')"
@@ -42,33 +42,33 @@ case "${1}" in
Create_lockfile .lock
# Configure custom sources.list
- echo "deb ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" > chroot/etc/apt/sources.list
+ echo "deb ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_ARCHIVE_AREAS}" > chroot/etc/apt/sources.list
if [ "${LH_SOURCE}" = "enabled" ]
then
- echo "deb-src ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb-src ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
fi
if [ "${LH_SECURITY}" = "enabled" ]
then
case "${LH_MODE}" in
ubuntu)
- echo "deb ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}-security ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}-security ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
if [ "${LH_SOURCE}" = "enabled" ]
then
- echo "deb-src ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}-security ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb-src ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}-security ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
fi
;;
*)
if [ "${LH_DISTRIBUTION}" != "sid" ] && [ "${LH_DISTRIBUTION}" != "unstable" ]
then
- echo "deb ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
if [ "${LH_SOURCE}" = "enabled" ]
then
- echo "deb-src ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb-src ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
fi
fi
;;
@@ -365,33 +365,33 @@ case "${1}" in
rm -rf chroot/var/lib/apt/lists
mkdir -p chroot/var/lib/apt/lists/partial
- echo "deb ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" > chroot/etc/apt/sources.list
+ echo "deb ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_ARCHIVE_AREAS}" > chroot/etc/apt/sources.list
if [ "${LH_SOURCE}" = "enabled" ]
then
- echo "deb-src ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb-src ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
fi
if [ "${LH_SECURITY}" = "enabled" ]
then
case "${LH_MODE}" in
ubuntu)
- echo "deb ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}-security ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}-security ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
if [ "${LH_SOURCE}" = "enabled" ]
then
- echo "deb-src ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}-security ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb-src ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}-security ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
fi
;;
*)
if [ "${LH_DISTRIBUTION}" != "sid" ] && [ "${LH_DISTRIBUTION}" != "unstable" ]
then
- echo "deb ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
if [ "${LH_SOURCE}" = "enabled" ]
then
- echo "deb-src ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
+ echo "deb-src ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list
fi
fi
;;
diff --git a/helpers/lh_chroot_symlinks b/helpers/lh_chroot_symlinks
index 69cbd20..abdbbf7 100755
--- a/helpers/lh_chroot_symlinks
+++ b/helpers/lh_chroot_symlinks
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'convert symlinks')"
diff --git a/helpers/lh_chroot_sysfs b/helpers/lh_chroot_sysfs
index 9906ad2..d68f3e6 100755
--- a/helpers/lh_chroot_sysfs
+++ b/helpers/lh_chroot_sysfs
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'mount /sys')"
diff --git a/helpers/lh_chroot_sysv-rc b/helpers/lh_chroot_sysv-rc
index 54aed0c..74a9702 100755
--- a/helpers/lh_chroot_sysv-rc
+++ b/helpers/lh_chroot_sysv-rc
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'manage /usr/sbin/policy-rc.d')"
diff --git a/helpers/lh_chroot_sysvinit b/helpers/lh_chroot_sysvinit
index d9caa04..0bd0db2 100755
--- a/helpers/lh_chroot_sysvinit
+++ b/helpers/lh_chroot_sysvinit
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'configure sysvinit')"
diff --git a/helpers/lh_chroot_tasks b/helpers/lh_chroot_tasks
index 0a7dddd..ff8e60a 100755
--- a/helpers/lh_chroot_tasks
+++ b/helpers/lh_chroot_tasks
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install tasks into chroot')"
diff --git a/helpers/lh_clean b/helpers/lh_clean
index 823b660..29bddbd 100755
--- a/helpers/lh_clean
+++ b/helpers/lh_clean
@@ -21,7 +21,7 @@ then
fi
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'clean up system build directories')"
diff --git a/helpers/lh_config b/helpers/lh_config
index d74b21d..58729d2 100755
--- a/helpers/lh_config
+++ b/helpers/lh_config
@@ -21,7 +21,7 @@ then
fi
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
SYSTEM_LH_CONFFILE="/etc/default/live-helper"
@@ -109,7 +109,7 @@ USAGE="${PROGRAM} [--apt apt|aptitude]\n\
\t [--quiet]\n\
\t [--root-command sudo]\n\
\t [--use-fakeroot enabled|disabled]\n\
-\t [--categories CATEGORY|\"CATEGORIES\"]\n\
+\t [--archive-areas ARCHIVE_AREA|\"ARCHIVE_AREAS\"]\n\
\t [--security enabled|disabled]\n\
\t [--source enabled|disabled]\n\
\t [-s|--source-images iso|net|tar|usb-hdd]\n\
@@ -136,7 +136,7 @@ Local_arguments ()
initramfs:,fdisk:,losetup:,mode:,root-command:,use-fakeroot:,tasksel:,includes:,
templates:,architecture:,bootstrap-config:,bootstrap-flavour:,bootstrap-keyring:,clean,
distribution:,mirror-bootstrap:,mirror-chroot:,mirror-chroot-security:,mirror-binary:,
- mirror-binary-security:,categories:,chroot-filesystem:,union-filesystem:,exposed-root:,virtual-root-size:,
+ mirror-binary-security:,archive-areas:,chroot-filesystem:,union-filesystem:,exposed-root:,virtual-root-size:,
gzip-options:,hooks:,interactive:,keyring-packages:,language:,linux-flavours:,linux-packages:,
packages:,packages-lists:,tasks:,security:,symlinks:,sysvinit:,binary-filesystem:,binary-images:,
binary-indices:,bootappend-install:,bootappend-live:,bootloader:,checksums:,chroot-build:,
@@ -409,8 +409,8 @@ Local_arguments ()
shift 2
;;
- --categories)
- LH_CATEGORIES="${2}"
+ --archive-areas)
+ LH_ARCHIVE_AREAS="${2}"
shift 2
;;
@@ -977,9 +977,9 @@ LH_MIRROR_BINARY="${LH_MIRROR_BINARY}"
# (Default: ${LH_MIRROR_BINARY_SECURITY})
LH_MIRROR_BINARY_SECURITY="${LH_MIRROR_BINARY_SECURITY}"
-# \$LH_CATEGORIES: select categories to use
-# (Default: ${LH_CATEGORIES})
-LH_CATEGORIES="${LH_CATEGORIES}"
+# \$LH_ARCHIVE_AREAS: select archive areas to use
+# (Default: ${LH_ARCHIVE_AREAS})
+LH_ARCHIVE_AREAS="${LH_ARCHIVE_AREAS}"
EOF
# Creating lh_chroot_* configuration
diff --git a/helpers/lh_source b/helpers/lh_source
index 84429e1..8d11c44 100755
--- a/helpers/lh_source
+++ b/helpers/lh_source
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build source images')"
diff --git a/helpers/lh_source_debian b/helpers/lh_source_debian
index 7b44345..b3cd08b 100755
--- a/helpers/lh_source_debian
+++ b/helpers/lh_source_debian
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'debian sources')"
diff --git a/helpers/lh_source_debian-live b/helpers/lh_source_debian-live
index 809794c..ecd12fd 100755
--- a/helpers/lh_source_debian-live
+++ b/helpers/lh_source_debian-live
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'copy debian-live config into source')"
diff --git a/helpers/lh_source_disk b/helpers/lh_source_disk
index a69be67..b52775f 100755
--- a/helpers/lh_source_disk
+++ b/helpers/lh_source_disk
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'install disk information into source')"
diff --git a/helpers/lh_source_iso b/helpers/lh_source_iso
index 4e15341..b65fae0 100755
--- a/helpers/lh_source_iso
+++ b/helpers/lh_source_iso
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build iso source image')"
diff --git a/helpers/lh_source_md5sum b/helpers/lh_source_md5sum
index 8d0a149..8f3fcdc 100755
--- a/helpers/lh_source_md5sum
+++ b/helpers/lh_source_md5sum
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'create source md5sums')"
diff --git a/helpers/lh_source_net b/helpers/lh_source_net
index eb32ed9..f10db28 100755
--- a/helpers/lh_source_net
+++ b/helpers/lh_source_net
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build source net image')"
diff --git a/helpers/lh_source_tar b/helpers/lh_source_tar
index cbf3f83..d8cb41a 100755
--- a/helpers/lh_source_tar
+++ b/helpers/lh_source_tar
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build source tarball')"
diff --git a/helpers/lh_source_usb-hdd b/helpers/lh_source_usb-hdd
index 3434fd5..a8183db 100755
--- a/helpers/lh_source_usb-hdd
+++ b/helpers/lh_source_usb-hdd
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build source image')"
diff --git a/helpers/lh_source_virtual-hdd b/helpers/lh_source_virtual-hdd
index e02f0a0..59ee2b5 100755
--- a/helpers/lh_source_virtual-hdd
+++ b/helpers/lh_source_virtual-hdd
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'build source image')"
diff --git a/helpers/lh_testroot b/helpers/lh_testroot
index fef9db8..c4a4276 100755
--- a/helpers/lh_testroot
+++ b/helpers/lh_testroot
@@ -10,7 +10,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
# Setting static variables
DESCRIPTION="$(Echo 'ensure that a system is built as root')"
diff --git a/helpers/live-helper b/helpers/live-helper
index e4ce2be..e551498 100755
--- a/helpers/live-helper
+++ b/helpers/live-helper
@@ -22,7 +22,7 @@
set -e
# Including common functions
-. "${LH_BASE:-/usr/share/live-helper}"/functions.sh
+. "${LH_BASE:-/usr/share/live-helper}"/live-helper.sh
if [ -x "$(which man 2>/dev/null)" ]
then
diff --git a/functions.sh b/live-helper.sh
index 626ba3f..626ba3f 100755
--- a/functions.sh
+++ b/live-helper.sh
diff --git a/manpages/lh_config.en.1 b/manpages/lh_config.en.1
index 598fe99..4abfba6 100644
--- a/manpages/lh_config.en.1
+++ b/manpages/lh_config.en.1
@@ -164,7 +164,7 @@ lh_config \- create configuration for live\-helper
.br
[\fB\-\-use-fakeroot\fR enabled|disabled]
.br
- [\fB\-\-categories\fR \fICATEGORY\fR|\fI"CATEGORIES"\fR]
+ [\fB\-\-archive\-areas\fR \fIARCHIVE_AREA\fR|\fI"ARCHIVE_AREAS"\fR]
.br
[\fB\-\-security\fR enabled|disabled]
.br
@@ -375,8 +375,8 @@ defines one or more packages to be installed in the live system. This is a quick
controls if live-helper should use sudo internally to build the live image. Note that this is not well tested and that you should, when relying on sudo, call the individual live\-helper command with sudo itself.
.IP "\fB\-\-use-fakeroot\fR enabled|disabled" 4
controls if live-helper should utilize fakeroot and fakechroot to try and avoid requiring root privillages where possible. By default, this option is disabled.
-.IP "\fB\-\-categories\fR \fICATEGORY\fR|\fI""CATEGORIES""\fR" 4
-defines which package categories of a debian packages archive should be used for configured debian package mirrors. By default, this is set to main. Remember to check the licenses of each packages with respect to their redistributability in your juristiction when enabling contrib or non-free with this mechanism.
+.IP "\fB\-\-archive\-areas\fR \fIARCHIVE_AREA\fR|\fI""ARCHIVE_AREAS""\fR" 4
+defines which package archive areas of a debian packages archive should be used for configured debian package mirrors. By default, this is set to main. Remember to check the licenses of each packages with respect to their redistributability in your juristiction when enabling contrib or non-free with this mechanism.
.IP "\fB\-\-security\fR enabled|disabled" 4
defines if the security repositories specified in the security mirror options should be used or not.
.IP "\fB\-\-source\fR enabled|disabled" 4
diff --git a/manpages/po4a/de/lh_config.en.1.po b/manpages/po4a/de/lh_config.en.1.po
index f8b0d6b..698aed7 100644
--- a/manpages/po4a/de/lh_config.en.1.po
+++ b/manpages/po4a/de/lh_config.en.1.po
@@ -565,8 +565,8 @@ msgstr " [B<--use-fakeroot> enabled|disabled]"
# type: Plain text
#: lh_config.en.1:164
-msgid " [B<--categories> I<CATEGORY>|I<\"CATEGORIES\">]"
-msgstr " [B<--categories> I<KATEGORIE>|I<\"KATEGORIEN\">]"
+msgid " [B<--archive-areas> I<ARCHIVE_AREA>|I<\"ARCHIVE_AREAS\">]"
+msgstr " [B<--archive-areas> I<KATEGORIE>|I<\"KATEGORIEN\">]"
# type: Plain text
#: lh_config.en.1:166
@@ -2136,13 +2136,13 @@ msgstr "B<--use-fakeroot> enabled|disabled"
# type: IP
#: lh_config.en.1:370
#, no-wrap
-msgid "B<--categories> I<CATEGORY>|I<\"CATEGORIES\">"
-msgstr "B<--categories> I<KATEGORIE>|I<\"KATEGORIEN\">"
+msgid "B<--archive-areas> I<ARCHIVE_AREA>|I<\"ARCHIVE_AREAS\">"
+msgstr "B<--archive-areas> I<KATEGORIE>|I<\"KATEGORIEN\">"
# type: Plain text
#: lh_config.en.1:372
msgid ""
-"defines which package categories of a debian packages archive should be used "
+"defines which package archive areas of a debian packages archive should be used "
"for configured debian package mirrors. By default, this is set to main. "
"Remember to check the licenses of each packages with respect to their "
"redistributability in your juristiction when enabling contrib or non-free "
diff --git a/manpages/po4a/fr/lh_config.en.1.po b/manpages/po4a/fr/lh_config.en.1.po
index 8be89b0..0f87f9b 100644
--- a/manpages/po4a/fr/lh_config.en.1.po
+++ b/manpages/po4a/fr/lh_config.en.1.po
@@ -557,7 +557,7 @@ msgstr ""
# type: Plain text
#: lh_config.en.1:164
-msgid " [B<--categories> I<CATEGORY>|I<\"CATEGORIES\">]"
+msgid " [B<--archive-areas> I<ARCHIVE_AREA>|I<\"ARCHIVE_AREAS\">]"
msgstr ""
# type: Plain text
@@ -1797,13 +1797,13 @@ msgstr ""
# type: IP
#: lh_config.en.1:370
#, no-wrap
-msgid "B<--categories> I<CATEGORY>|I<\"CATEGORIES\">"
+msgid "B<--archive-areas> I<ARCHIVE_AREA>|I<\"ARCHIVE_AREAS\">"
msgstr ""
# type: Plain text
#: lh_config.en.1:372
msgid ""
-"defines which package categories of a debian packages archive should be used "
+"defines which package archive areas of a debian packages archive should be used "
"for configured debian package mirrors. By default, this is set to main. "
"Remember to check the licenses of each packages with respect to their "
"redistributability in your juristiction when enabling contrib or non-free "
diff --git a/manpages/po4a/pot/lh_config.en.1.pot b/manpages/po4a/pot/lh_config.en.1.pot
index e47042d..035afef 100644
--- a/manpages/po4a/pot/lh_config.en.1.pot
+++ b/manpages/po4a/pot/lh_config.en.1.pot
@@ -550,7 +550,7 @@ msgstr ""
# type: Plain text
#: lh_config.en.1:164
-msgid " [B<--categories> I<CATEGORY>|I<\"CATEGORIES\">]"
+msgid " [B<--archive-areas> I<ARCHIVE_AREA>|I<\"ARCHIVE_AREAS\">]"
msgstr ""
# type: Plain text
@@ -1789,13 +1789,13 @@ msgstr ""
# type: IP
#: lh_config.en.1:370
#, no-wrap
-msgid "B<--categories> I<CATEGORY>|I<\"CATEGORIES\">"
+msgid "B<--archive-areas> I<ARCHIVE_AREA>|I<\"ARCHIVE_AREAS\">"
msgstr ""
# type: Plain text
#: lh_config.en.1:372
msgid ""
-"defines which package categories of a debian packages archive should be used "
+"defines which package archive areas of a debian packages archive should be used "
"for configured debian package mirrors. By default, this is set to main. "
"Remember to check the licenses of each packages with respect to their "
"redistributability in your juristiction when enabling contrib or non-free "
diff --git a/functions/defaults.sh b/functions/defaults.sh
index 399c582..30cdfc6 100755
--- a/functions/defaults.sh
+++ b/functions/defaults.sh
@@ -405,16 +405,16 @@ Set_defaults ()
esac
fi
- # Setting categories value
- if [ -z "${LH_CATEGORIES}" ]
+ # Setting archive areas value
+ if [ -z "${LH_ARCHIVE_AREAS}" ]
then
case "${LH_MODE}" in
ubuntu)
- LH_CATEGORIES="main restricted"
+ LH_ARCHIVE_AREAS="main restricted"
;;
*)
- LH_CATEGORIES="main"
+ LH_ARCHIVE_AREAS="main"
;;
esac
fi